@@ -177,7 +177,11 @@ GUM <- function(data, C, SE = TRUE, precision = 4,
                                param = "taus")
       D1             <- DlogL.dphi(param = "taus", dP, r.bar.izf.taus, 
                                    P.izf.arr.taus)
-      DlogL.taus     <- colSums(D1$taus)
+      
+      # Dirty fix for R 4.1:
+      tmp.dims   <- dim(D1$taus)
+      DlogL.taus <- colSums(matrix(unlist(D1$taus), tmp.dims))
+      
       # 
       P.izf.arr.taus.taus <- array(rep(P.izf.arr.taus, C.max), 
                                    dim = c(N.nodes, I, C.max + 1, C.max, C.max))
@@ -223,7 +227,8 @@ GUM <- function(data, C, SE = TRUE, precision = 4,
       Inf.arr        <- apply(N.bar.if.arr * dP.delta.delta / P.izf.arr, 2, 
                               sum, na.rm = TRUE)
       # 
-      delta.new <- delta.old + (1/Inf.arr) * DlogL.delta
+      # Dirty fix for R 4.1:
+      delta.new <- delta.old + (1/Inf.arr) * unlist(DlogL.delta)
       # Extra control (needed in weird cases):
       delta.new[delta.new < -10] <- -10
       delta.new[delta.new >  10] <-  10
